@@ -25,13 +25,13 @@ class Service:
             action = data['action'] if 'action' in data else None
             payload = json.dumps(body)  # Somente o corpo da requisição
 
-            url = self.server + action
+            url = self.server + service + ('/' + action if action else '')  # Montar URL
 
             headers = {
                 'Content-Type': 'application/json',
                 'Authorization': 'Bearer ' + credentials['BearerToken'],
                 'DeviceToken': credentials['DeviceToken'],
-                'User-Agent': 'APIBRASIL/PYTHON-SDK'
+                'User-Agent': 'APIBrasil/Python-SDK'
             }
 
             response = requests.post(url, headers=headers, data=payload, allow_redirects=False, stream=True)
@@ -62,3 +62,6 @@ class Service:
 
     def cpf(self, dados):
         return self.request('dados/cpf', dados)
+
+    def sms(self, dados):
+        return self.request('sms', dados)
